import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { useTransactions } from "@/contexts/TransactionContext";
import { useState, useEffect } from "react";
import { useToast } from "@/hooks/use-toast";
import { Checkbox } from "@/components/ui/checkbox";
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { TransactionType } from "@/types";

const formSchema = z.object({
  startingBalance: z.string().optional(),
  transactionType: z.enum(["receive", "send", "load-wallet"]),
  accountNumber: z.string().min(1, "Account number is required"),
  referenceNumber: z.string().min(1, "Reference number is required"),
  amount: z.string().refine((val) => !isNaN(Number(val)) && Number(val) > 0, {
    message: "Amount must be a positive number",
  }),
  autoServiceCharge: z.boolean().optional(),
  serviceChargeAmount: z.string().optional(),
  description: z.string().min(1, "Description is required"),
  transactionDate: z.string().min(1, "Date is required"),
});

type FormValues = z.infer<typeof formSchema>;

export default function TransactionForm() {
  const { toast } = useToast();
  const { 
    isInitialBalanceSet, 
    setInitialBalance, 
    addTransaction, 
    currentBalance 
  } = useTransactions();
  
  const [showManualServiceCharge, setShowManualServiceCharge] = useState(true);

  const today = new Date().toISOString().split("T")[0];

  const form = useForm<FormValues>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      transactionType: "receive",
      accountNumber: "",
      referenceNumber: "",
      amount: "",
      description: "",
      transactionDate: today,
      autoServiceCharge: false,
      serviceChargeAmount: "0",
    },
  });

  const watchAmount = form.watch("amount");
  const watchAutoServiceCharge = form.watch("autoServiceCharge");
  const watchTransactionType = form.watch("transactionType");

  // Show/hide manual service charge input based on auto checkbox
  useEffect(() => {
    setShowManualServiceCharge(!watchAutoServiceCharge);
  }, [watchAutoServiceCharge]);

  // Auto-calculate service charge when amount changes
  useEffect(() => {
    if (watchAutoServiceCharge) {
      const amount = parseFloat(watchAmount) || 0;
      const serviceCharge = (amount * 0.02).toFixed(2);
      form.setValue("serviceChargeAmount", serviceCharge);
    }
  }, [watchAmount, watchAutoServiceCharge, form]);

  const handleSetInitialBalance = () => {
    const balance = form.getValues("startingBalance");
    const initialBalance = parseFloat(balance || "0");

    if (isNaN(initialBalance) || initialBalance < 0) {
      toast({
        title: "Error",
        description: "Please enter a valid starting balance",
        variant: "destructive",
      });
      return;
    }

    // Show warning if already set (since it will reset transactions)
    if (isInitialBalanceSet) {
      if (!confirm("Changing the initial balance will reset all transactions. Do you want to continue?")) {
        return;
      }
    }

    setInitialBalance(initialBalance);
    toast({
      title: "Success",
      description: isInitialBalanceSet 
        ? "Initial balance updated and transactions reset" 
        : "Initial balance set successfully",
    });
  };

  const onSubmit = (data: FormValues) => {
    if (!isInitialBalanceSet) {
      toast({
        title: "Error",
        description: "Please set the initial balance first",
        variant: "destructive",
      });
      return;
    }

    const amount = parseFloat(data.amount);
    const type = data.transactionType;
    let serviceCharge = 0;

    // Calculate service charge for both transaction types
    if (data.autoServiceCharge) {
      // Automatic 2% service charge
      serviceCharge = parseFloat((amount * 0.02).toFixed(2));
    } else {
      // Manual service charge
      serviceCharge = parseFloat(data.serviceChargeAmount || "0");
      if (isNaN(serviceCharge) || serviceCharge < 0) {
        toast({
          title: "Error",
          description: "Please enter a valid service charge amount",
          variant: "destructive",
        });
        return;
      }
    }

    // Validate if there's enough balance for sending money or loading wallet
    const needsBalanceCheck = ["send", "load-wallet"].includes(type as string);
    
    if (needsBalanceCheck && amount > currentBalance) {
      toast({
        title: "Error",
        description: "Insufficient balance for this transaction",
        variant: "destructive",
      });
      return;
    }

    try {
      addTransaction({
        type: data.transactionType,
        accountNumber: data.accountNumber,
        reference: data.referenceNumber,
        amount,
        serviceCharge,
        description: data.description,
        date: data.transactionDate,
      });

      form.reset({
        transactionType: "receive",
        accountNumber: "",
        referenceNumber: "",
        amount: "",
        description: "",
        transactionDate: today,
        autoServiceCharge: false,
        serviceChargeAmount: "",
      });

      toast({
        title: "Success",
        description: "Transaction added successfully",
      });
    } catch (error) {
      toast({
        title: "Error",
        description: "Failed to add transaction",
        variant: "destructive",
      });
    }
  };

  return (
    <div className="bg-white rounded-lg shadow p-6">
      <h2 className="text-lg font-semibold text-gray-800 mb-4">New Transaction</h2>
      
      <div className="mb-4">
        <Label htmlFor="starting-balance" className="block text-sm font-medium text-gray-700 mb-1">
          {isInitialBalanceSet ? "Change Starting Balance" : "Starting Balance"}
        </Label>
        <div className="relative">
          <span className="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">₱</span>
          <Input
            id="starting-balance"
            type="number"
            className="pl-8"
            placeholder="0.00"
            step="0.01"
            {...form.register("startingBalance")}
          />
        </div>
        <Button 
          type="button" 
          className="mt-2 w-full"
          onClick={handleSetInitialBalance}
        >
          {isInitialBalanceSet ? "Update Balance" : "Set Initial Balance"}
        </Button>
      </div>

      <Form {...form}>
        <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-4">
          <FormField
            control={form.control}
            name="transactionType"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Transaction Type</FormLabel>
                <Select
                  onValueChange={field.onChange}
                  defaultValue={field.value}
                >
                  <FormControl>
                    <SelectTrigger>
                      <SelectValue placeholder="Select transaction type" />
                    </SelectTrigger>
                  </FormControl>
                  <SelectContent>
                    <SelectItem value="receive">Receive Money</SelectItem>
                    <SelectItem value="send">Send Money</SelectItem>
                    <SelectItem value="load-wallet">Load Wallet</SelectItem>
                  </SelectContent>
                </Select>
                <FormMessage />
              </FormItem>
            )}
          />

          <FormField
            control={form.control}
            name="accountNumber"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Account Number</FormLabel>
                <FormControl>
                  <Input placeholder="e.g. 123456789" {...field} />
                </FormControl>
                <FormMessage />
              </FormItem>
            )}
          />

          <FormField
            control={form.control}
            name="referenceNumber"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Reference Number</FormLabel>
                <FormControl>
                  <Input placeholder="e.g. 43210" {...field} />
                </FormControl>
                <FormMessage />
              </FormItem>
            )}
          />

          <FormField
            control={form.control}
            name="amount"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Amount</FormLabel>
                <div className="relative">
                  <span className="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">₱</span>
                  <FormControl>
                    <Input className="pl-8" type="number" step="0.01" placeholder="0.00" {...field} />
                  </FormControl>
                </div>
                <FormMessage />
              </FormItem>
            )}
          />

          <FormField
            control={form.control}
            name="autoServiceCharge"
            render={({ field }) => (
              <FormItem className="flex flex-row items-start space-x-3 space-y-0 rounded-md">
                <FormControl>
                  <Checkbox
                    checked={field.value}
                    onCheckedChange={field.onChange}
                  />
                </FormControl>
                <div className="space-y-1 leading-none">
                  <FormLabel>Calculate 2% service charge automatically</FormLabel>
                  {watchTransactionType === "load-wallet" && (
                    <p className="text-xs text-blue-600 mt-1">
                      Note: Service charges for Load Wallet are tracked separately and added to total charges.
                    </p>
                  )}
                </div>
              </FormItem>
            )}
          />

          {showManualServiceCharge && (
            <FormField
              control={form.control}
              name="serviceChargeAmount"
              render={({ field }) => (
                <FormItem>
                  <FormLabel>Service Charge Amount</FormLabel>
                  <div className="relative">
                    <span className="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">₱</span>
                    <FormControl>
                      <Input className="pl-8" type="number" step="0.01" placeholder="0.00" {...field} />
                    </FormControl>
                  </div>
                  {watchTransactionType === "load-wallet" && (
                    <p className="text-xs text-blue-600 mt-1">
                      Note: For Load Wallet transactions, service charges are tracked separately and do not affect your balance.
                    </p>
                  )}
                  <FormMessage />
                </FormItem>
              )}
            />
          )}

          <FormField
            control={form.control}
            name="description"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Description</FormLabel>
                <FormControl>
                  <Input placeholder="e.g. Payment for invoice #456" {...field} />
                </FormControl>
                <FormMessage />
              </FormItem>
            )}
          />

          <FormField
            control={form.control}
            name="transactionDate"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Transaction Date</FormLabel>
                <FormControl>
                  <Input type="date" {...field} />
                </FormControl>
                <FormMessage />
              </FormItem>
            )}
          />

          <Button type="submit" className="w-full">
            Add Transaction
          </Button>
        </form>
      </Form>
    </div>
  );
}
