import { Transaction } from "@/types";
import { formatCurrency } from "@/utils/format";
import { 
  ArrowUpIcon, 
  ArrowDownIcon, 
  PercentIcon, 
  CheckCircleIcon,
  WalletIcon
} from "lucide-react";

interface TransactionItemProps {
  transaction: Transaction;
}

export default function TransactionItem({ transaction }: TransactionItemProps) {
  const getTypeIcon = () => {
    switch (transaction.type) {
      case "send":
        return <ArrowUpIcon className="h-4 w-4" />;
      case "receive":
        return <ArrowDownIcon className="h-4 w-4" />;
      case "load-wallet":
        return <WalletIcon className="h-4 w-4" />;
      default:
        return null;
    }
  };

  const getTypeColor = () => {
    switch (transaction.type) {
      case "send":
        return "bg-error";
      case "receive":
        return "bg-success";
      case "load-wallet":
        return "bg-blue-500";
      default:
        return "bg-gray-500";
    }
  };

  const getHeaderColor = () => {
    switch (transaction.type) {
      case "send":
        return "bg-red-50";
      case "receive":
        return "bg-green-50";
      case "load-wallet":
        return "bg-blue-50";
      default:
        return "bg-gray-50";
    }
  };

  const getAmountColor = () => {
    switch (transaction.type) {
      case "send":
        return "text-error";
      case "receive":
        return "text-success";
      case "load-wallet":
        return "text-blue-600";
      default:
        return "text-gray-900";
    }
  };

  const getAmountDisplay = () => {
    switch (transaction.type) {
      case "send":
        return `-${formatCurrency(transaction.amount)}`;
      case "receive":
        return `+${formatCurrency(transaction.amount)}`;
      case "load-wallet":
        return `-${formatCurrency(transaction.amount)}`;
      default:
        return formatCurrency(transaction.amount);
    }
  };

  const getTransactionTitle = () => {
    switch (transaction.type) {
      case "send":
        return "Money Sent";
      case "receive":
        return "Money Received";
      case "load-wallet":
        return "Wallet Loaded";
      default:
        return "Transaction";
    }
  };

  const formattedDate = new Date(transaction.date).toLocaleDateString("en-US", {
    year: "numeric",
    month: "short",
    day: "numeric",
  });

  return (
    <div className="bg-white rounded-lg shadow overflow-hidden">
      <div className={`p-4 flex items-center justify-between ${getHeaderColor()}`}>
        <div className="flex items-center">
          <div className={`rounded-full w-10 h-10 flex items-center justify-center text-white mr-3 ${getTypeColor()}`}>
            {getTypeIcon()}
          </div>
          <div>
            <h3 className="font-medium">{getTransactionTitle()}</h3>
            <div className="text-sm text-gray-500">{formattedDate}</div>
          </div>
        </div>
        <div className="text-right">
          <div className={`font-semibold ${getAmountColor()}`}>{getAmountDisplay()}</div>
          <div className="bg-green-100 text-green-800 text-sm rounded-full px-2 py-0.5 inline-block">
            {transaction.status}
          </div>
        </div>
      </div>
      <div className="p-4 bg-gray-50 grid grid-cols-2 gap-3 text-sm border-t">
        <div>
          <div className="text-gray-500">Account Number</div>
          <div className="font-medium">{transaction.accountNumber}</div>
        </div>
        <div>
          <div className="text-gray-500">Reference</div>
          <div className="font-medium">{transaction.reference}</div>
        </div>
        <div>
          <div className="text-gray-500">Amount</div>
          <div className="font-medium">{formatCurrency(transaction.amount)}</div>
        </div>
        <div>
          <div className="text-gray-500">Service Charge</div>
          <div className="font-medium text-warning">{formatCurrency(transaction.serviceCharge)}</div>
        </div>
        <div>
          <div className="text-gray-500">Before Balance</div>
          <div className="font-medium">{formatCurrency(transaction.beforeBalance)}</div>
        </div>
        <div>
          <div className="text-gray-500">After Balance</div>
          <div className="font-medium">{formatCurrency(transaction.afterBalance)}</div>
        </div>
        <div className="col-span-2">
          <div className="text-gray-500">Description</div>
          <div className="font-medium">{transaction.description}</div>
        </div>
      </div>
    </div>
  );
}
