import { useState, useEffect } from "react";
import { useTransactions } from "@/contexts/TransactionContext";
import TransactionItem from "./TransactionItem";
import TransactionPagination from "./TransactionPagination";
import { Button } from "@/components/ui/button";
import { DownloadIcon, TableIcon, SmartphoneIcon } from "lucide-react";
import { generateTransactionPDF } from "@/utils/pdfGenerator";
import { useIsMobile } from "@/hooks/use-mobile";

// Number of transactions to show per page
const ITEMS_PER_PAGE = 5;

export default function TransactionList() {
  const { filteredTransactions } = useTransactions();
  const [currentPage, setCurrentPage] = useState(1);
  const [displayMode, setDisplayMode] = useState<"list" | "table">("list");
  
  // Get viewport info
  const isMobile = useIsMobile();

  // Reset to page 1 when filtered transactions change
  useEffect(() => {
    setCurrentPage(1);
  }, [filteredTransactions.length]);

  // Calculate total pages
  const totalPages = Math.max(1, Math.ceil(filteredTransactions.length / ITEMS_PER_PAGE));
  
  // Get current page transactions
  const startIndex = (currentPage - 1) * ITEMS_PER_PAGE;
  const endIndex = startIndex + ITEMS_PER_PAGE;
  const currentTransactions = filteredTransactions.slice(startIndex, endIndex);
  
  // Handle page change
  const handlePageChange = (page: number) => {
    setCurrentPage(page);
  };
  
  // Handle download as PDF
  const handleDownloadPDF = () => {
    generateTransactionPDF(filteredTransactions);
  };

  if (filteredTransactions.length === 0) {
    return (
      <div className="bg-white rounded-lg shadow p-6 text-center text-gray-500">
        <svg
          className="w-12 h-12 mx-auto mb-2 text-gray-400"
          fill="none"
          viewBox="0 0 24 24"
          stroke="currentColor"
          xmlns="http://www.w3.org/2000/svg"
        >
          <path
            strokeLinecap="round"
            strokeLinejoin="round"
            strokeWidth={2}
            d="M9 12h6m-6 4h6m2 5H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z"
          />
        </svg>
        <p>No transactions found. Start by adding a new transaction.</p>
      </div>
    );
  }

  return (
    <div className="space-y-4">
      <div className="flex justify-between items-center mb-4">
        <div className="flex space-x-2">
          {/* Only show view toggle on mobile */}
          {isMobile && (
            <>
              <Button 
                variant={displayMode === "list" ? "default" : "outline"} 
                size="sm"
                onClick={() => setDisplayMode("list")}
              >
                <SmartphoneIcon className="h-4 w-4 mr-2" />
                Card View
              </Button>
              <Button 
                variant={displayMode === "table" ? "default" : "outline"} 
                size="sm"
                onClick={() => setDisplayMode("table")}
              >
                <TableIcon className="h-4 w-4 mr-2" />
                Table View
              </Button>
            </>
          )}
        </div>
        <Button 
          variant="outline" 
          size="sm"
          onClick={handleDownloadPDF}
        >
          <DownloadIcon className="h-4 w-4 mr-2" />
          Export PDF
        </Button>
      </div>

      {/* Card view for mobile or desktop */}
      {(!isMobile || displayMode === "list") && (
        <div className="space-y-4">
          {currentTransactions.map((transaction) => (
            <TransactionItem key={transaction.id} transaction={transaction} />
          ))}
        </div>
      )}

      {/* Table view for mobile only */}
      {isMobile && displayMode === "table" && (
        <div className="overflow-x-auto">
          <table className="min-w-full bg-white border border-gray-200 rounded-lg shadow">
            <thead className="bg-gray-50">
              <tr>
                <th className="py-2 px-3 text-left text-xs font-medium text-gray-500 uppercase">Date</th>
                <th className="py-2 px-3 text-left text-xs font-medium text-gray-500 uppercase">Type</th>
                <th className="py-2 px-3 text-left text-xs font-medium text-gray-500 uppercase">Amount</th>
              </tr>
            </thead>
            <tbody className="divide-y divide-gray-200">
              {currentTransactions.map((transaction) => (
                <tr key={transaction.id}>
                  <td className="px-3 py-2 text-sm">{new Date(transaction.date).toLocaleDateString()}</td>
                  <td className="px-3 py-2 text-sm capitalize">{transaction.type}</td>
                  <td className={`px-3 py-2 text-sm font-medium ${
                    transaction.type === "receive" ? "text-success" : "text-error"
                  }`}>
                    {transaction.type === "receive" ? "+" : "-"}₱{transaction.amount.toFixed(2)}
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      )}

      {/* Pagination */}
      <TransactionPagination 
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={handlePageChange}
      />
    </div>
  );
}
