import React, { createContext, useState, useContext, useEffect } from "react";
import { Transaction, NewTransaction } from "@/types";
import { useToast } from "@/hooks/use-toast";

interface TransactionContextProps {
  transactions: Transaction[];
  filteredTransactions: Transaction[];
  currentBalance: number;
  isInitialBalanceSet: boolean;
  setInitialBalance: (amount: number) => void;
  addTransaction: (newTransaction: NewTransaction) => void;
  setDateFilter: (date: string) => void;
  clearDateFilter: () => void;
}

const TransactionContext = createContext<TransactionContextProps | undefined>(undefined);

interface TransactionProviderProps {
  children: React.ReactNode;
}

export const TransactionProvider: React.FC<TransactionProviderProps> = ({ children }) => {
  const { toast } = useToast();
  const [transactions, setTransactions] = useState<Transaction[]>([]);
  const [currentBalance, setCurrentBalance] = useState(0);
  const [isInitialBalanceSet, setIsInitialBalanceSet] = useState(false);
  const [dateFilter, setDateFilter] = useState<string | null>(null);

  // Load data from localStorage on component mount
  useEffect(() => {
    try {
      const savedData = localStorage.getItem("moneyTransferData");
      if (savedData) {
        const parsedData = JSON.parse(savedData);
        setTransactions(parsedData.transactions || []);
        setCurrentBalance(parsedData.currentBalance || 0);
        setIsInitialBalanceSet(parsedData.isInitialBalanceSet || false);
      }
    } catch (error) {
      toast({
        title: "Error",
        description: "Failed to load data from local storage",
        variant: "destructive",
      });
    }
  }, [toast]);

  // Save data to localStorage when state changes
  useEffect(() => {
    try {
      const data = {
        transactions,
        currentBalance,
        isInitialBalanceSet,
      };
      localStorage.setItem("moneyTransferData", JSON.stringify(data));
    } catch (error) {
      toast({
        title: "Error",
        description: "Failed to save data to local storage",
        variant: "destructive",
      });
    }
  }, [transactions, currentBalance, isInitialBalanceSet, toast]);

  // Set the initial balance and reset transactions if already set
  const setInitialBalance = (amount: number) => {
    // If balance was already set, reset transactions
    if (isInitialBalanceSet) {
      setTransactions([]);
    }
    
    setCurrentBalance(amount);
    setIsInitialBalanceSet(true);
  };

  // Add a new transaction
  const addTransaction = (newTransaction: NewTransaction) => {
    const beforeBalance = currentBalance;
    let afterBalance = beforeBalance;

    // Calculate the new balance based on the transaction type
    if (newTransaction.type === "receive") {
      // For receive, just add the amount
      afterBalance = beforeBalance + newTransaction.amount;
    } else if (newTransaction.type === "send" || newTransaction.type === "load-wallet") {
      // For send and load-wallet, just subtract the amount
      // Service charge is tracked separately and doesn't affect the balance
      afterBalance = beforeBalance - newTransaction.amount;
    }

    // Create the transaction object
    const transaction: Transaction = {
      id: Date.now().toString(),
      ...newTransaction,
      beforeBalance,
      afterBalance,
      status: "Success",
      timestamp: new Date().toISOString(),
    };

    // Update state
    setTransactions([transaction, ...transactions]);
    setCurrentBalance(afterBalance);
  };

  const clearDateFilter = () => {
    setDateFilter(null);
  };

  // Filter transactions by date
  const filteredTransactions = dateFilter
    ? transactions.filter((t) => t.date === dateFilter)
    : transactions;

  return (
    <TransactionContext.Provider
      value={{
        transactions,
        filteredTransactions,
        currentBalance,
        isInitialBalanceSet,
        setInitialBalance,
        addTransaction,
        setDateFilter,
        clearDateFilter,
      }}
    >
      {children}
    </TransactionContext.Provider>
  );
};

export const useTransactions = () => {
  const context = useContext(TransactionContext);
  if (context === undefined) {
    throw new Error("useTransactions must be used within a TransactionProvider");
  }
  return context;
};
