import jsPDF from 'jspdf';
import autoTable from 'jspdf-autotable';
import { Transaction } from '@/types';
import { formatCurrency } from './format';

export function generateTransactionPDF(transactions: Transaction[]): void {
  // Create a new PDF document
  const doc = new jsPDF();
  
  // Add title
  doc.setFontSize(18);
  doc.text('Transaction Records', 14, 22);
  
  // Add date
  doc.setFontSize(11);
  doc.text(`Generated on: ${new Date().toLocaleDateString()}`, 14, 30);
  
  // Prepare table data
  const tableColumn = [
    'Date', 
    'Type', 
    'Account No.', 
    'Description', 
    'Amount', 
    'Service Charge', 
    'Balance After'
  ];
  
  const tableRows = transactions.map(transaction => [
    new Date(transaction.date).toLocaleDateString(),
    transaction.type.charAt(0).toUpperCase() + transaction.type.slice(1),
    transaction.accountNumber,
    transaction.description,
    formatCurrency(transaction.amount),
    formatCurrency(transaction.serviceCharge),
    formatCurrency(transaction.afterBalance)
  ]);

  // Generate the table
  autoTable(doc, {
    head: [tableColumn],
    body: tableRows,
    startY: 40,
    styles: { fontSize: 9 },
    headStyles: { fillColor: [52, 152, 219] },
    alternateRowStyles: { fillColor: [240, 240, 240] },
    margin: { top: 40 }
  });

  // Generate a summary section
  const totalReceived = transactions
    .filter(t => t.type === 'receive')
    .reduce((sum, t) => sum + t.amount, 0);
    
  const totalSent = transactions
    .filter(t => t.type === 'send')
    .reduce((sum, t) => sum + t.amount, 0);
    
  const totalServiceCharges = transactions
    .reduce((sum, t) => sum + t.serviceCharge, 0);

  // Calculate the Y position for the summary (after the table)
  const finalY = (doc as any).lastAutoTable.finalY || 120;
  
  doc.text('Summary:', 14, finalY + 10);
  doc.text(`Total Received: ${formatCurrency(totalReceived)}`, 14, finalY + 20);
  doc.text(`Total Sent: ${formatCurrency(totalSent)}`, 14, finalY + 30);
  doc.text(`Total Service Charges: ${formatCurrency(totalServiceCharges)}`, 14, finalY + 40);
  
  // Save the PDF
  doc.save('transaction-records.pdf');
}